summaryrefslogtreecommitdiff
path: root/examples/hlapi
diff options
context:
space:
mode:
authorIlya Etingof <etingof@gmail.com>2016-03-08 22:13:34 +0100
committerIlya Etingof <etingof@gmail.com>2016-03-08 22:13:34 +0100
commit84001b6939e2334113df601a7c8d3716ab70bd10 (patch)
tree020126d09628d9f4c8a7c08a9ce39482dfe3b683 /examples/hlapi
parent2b85c6b1529372b88a720f6d355bd616fb7c65d7 (diff)
downloadpysnmp-git-84001b6939e2334113df601a7c8d3716ab70bd10.tar.gz
example on implicit notification objects initialization improved
Diffstat (limited to 'examples/hlapi')
-rw-r--r--examples/hlapi/asyncore/sync/agent/ntforg/v2c-trap-with-notification-objects.py (renamed from examples/hlapi/asyncore/sync/agent/ntforg/v2c-trap-via-notification-type.py)13
1 files changed, 9 insertions, 4 deletions
diff --git a/examples/hlapi/asyncore/sync/agent/ntforg/v2c-trap-via-notification-type.py b/examples/hlapi/asyncore/sync/agent/ntforg/v2c-trap-with-notification-objects.py
index 60bd2b6b..5f59738a 100644
--- a/examples/hlapi/asyncore/sync/agent/ntforg/v2c-trap-via-notification-type.py
+++ b/examples/hlapi/asyncore/sync/agent/ntforg/v2c-trap-with-notification-objects.py
@@ -9,12 +9,13 @@ in *NOTIFICATION-TYPE* SMI macro.
* with community name 'public'
* over IPv4/UDP
* send TRAP notification
-* with TRAP ID 'coldStart' specified as a MIB symbol
-* include managed object information specified as a MIB symbol
+* with TRAP ID 'linkUp' specified as a MIB symbol
+* include values for managed objects implicitly added to notification
+ (via NOTIFICATION-TYPE->OBJECTS)
Functionally similar to:
-| $ snmptrap -v2c -c public demo.snmplabs.com 12345 1.3.6.1.4.1.20408.4.1.1.2
+| $ snmptrap -v2c -c public demo.snmplabs.com 0 1.3.6.1.6.3.1.1.5.1 1.3.6.1.2.1.2.2.1.1.123 i 123 1.3.6.1.2.1.2.2.1.7.123 i 1 1.3.6.1.2.1.2.2.1.8.123 i 1
"""#
from pysnmp.hlapi import *
@@ -26,7 +27,11 @@ errorIndication, errorStatus, errorIndex, varBinds = next(
ContextData(),
'trap',
NotificationType(
- ObjectIdentity('SNMPv2-MIB', 'coldStart')
+ ObjectIdentity('IF-MIB', 'linkUp'),
+ instanceIndex=(123,),
+ objects={('IF-MIB', 'ifIndex'): 123,
+ ('IF-MIB', 'ifAdminStatus'): 'up',
+ ('IF-MIB', 'ifOperStatus'): 'up'}
)
)
)